Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(600)

Unified Diff: third_party/WebKit/Source/core/page/FrameTree.cpp

Issue 1635873003: Replicating WebFrame::uniqueName across renderers. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@dump-render-tree3
Patch Set: Added FrameTreeHelpers::createLocalChild. Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/page/FrameTree.cpp
diff --git a/third_party/WebKit/Source/core/page/FrameTree.cpp b/third_party/WebKit/Source/core/page/FrameTree.cpp
index a4816ad06203d02d9e3da21a00efa598bef03ea6..dfaa39d2d494ea22d5909376c761659739bf44c5 100644
--- a/third_party/WebKit/Source/core/page/FrameTree.cpp
+++ b/third_party/WebKit/Source/core/page/FrameTree.cpp
@@ -58,12 +58,21 @@ void FrameTree::setName(const AtomicString& name, const AtomicString& fallbackNa
m_uniqueName = name;
return;
}
- m_uniqueName = AtomicString(); // Remove our old frame name so it's not considered in uniqueChildName.
- m_uniqueName = parent()->tree().uniqueChildName(name.isEmpty() ? fallbackName : name);
+
+ // Remove our old frame name so it's not considered in calculateUniqueNameForChildFrame.
+ m_uniqueName = AtomicString();
+
+ m_uniqueName = parent()->tree().calculateUniqueNameForChildFrame(true, name, fallbackName);
}
-void FrameTree::setNameForReplacementFrame(const AtomicString& name, const AtomicString& uniqueName)
+void FrameTree::setPrecalculatedName(const AtomicString& name, const AtomicString& uniqueName)
{
+ if (!parent()) {
+ ASSERT(uniqueName == name);
+ } else {
+ ASSERT(!uniqueName.isEmpty());
+ }
+
m_name = name;
m_uniqueName = uniqueName;
}
@@ -123,8 +132,20 @@ bool FrameTree::uniqueNameExists(const AtomicString& name) const
return false;
}
-AtomicString FrameTree::uniqueChildName(const AtomicString& requestedName) const
+AtomicString FrameTree::calculateUniqueNameForNewChildFrame(
+ const AtomicString& name,
+ const AtomicString& fallbackName) const
+{
+ return calculateUniqueNameForChildFrame(false, name, fallbackName);
+}
+
+AtomicString FrameTree::calculateUniqueNameForChildFrame(
+ bool existingChildFrame,
+ const AtomicString& originalRequestedName,
dcheng 2016/02/19 21:36:27 Nit: this doesn't match the name in the declaratio
Łukasz Anforowicz 2016/02/19 22:10:09 Done (+ renamed the other |name| below to |uniqueN
+ const AtomicString& fallbackName) const
{
+ const AtomicString& requestedName =
+ originalRequestedName.isEmpty() ? fallbackName : originalRequestedName;
if (!requestedName.isEmpty() && !uniqueNameExists(requestedName) && requestedName != "_blank")
return requestedName;
@@ -160,7 +181,7 @@ AtomicString FrameTree::uniqueChildName(const AtomicString& requestedName) const
}
name.appendLiteral("/<!--frame");
- name.appendNumber(childCount() - 1);
+ name.appendNumber(childCount() - (existingChildFrame ? 1 : 0));
name.appendLiteral("-->-->");
return name.toAtomicString();

Powered by Google App Engine
This is Rietveld 408576698